@@ -7,6 +7,9 @@
 #include <sys/mman.h>
 #include <unistd.h>
 
+#ifndef R_NO_REMAP
+#  define R_NO_REMAP
+#endif
 #include <R.h>
 #include <Rinternals.h>
 #include <R_ext/BLAS.h>
@@ -35,32 +38,32 @@ SEXP tgs_cor(SEXP _x, SEXP _pairwise_complete_obs, SEXP _spearman, SEXP _tidy, S
 	try {
         TGStat tgstat(_envir);
 
-		if ((!isReal(_x) && !isInteger(_x)) || xlength(_x) < 1)
+		if ((!Rf_isReal(_x) && !Rf_isInteger(_x)) || Rf_xlength(_x) < 1)
 			verror("\"x\" argument must be a matrix of numeric values");
 
-        if (!isLogical(_pairwise_complete_obs) || xlength(_pairwise_complete_obs) != 1)
+        if (!Rf_isLogical(_pairwise_complete_obs) || Rf_xlength(_pairwise_complete_obs) != 1)
             verror("\"pairwise.complete.obs\" argument must be a logical value");
 
-        if (!isLogical(_spearman) || xlength(_spearman) != 1)
+        if (!Rf_isLogical(_spearman) || Rf_xlength(_spearman) != 1)
             verror("\"spearman\" argument must be a logical value");
 
-        if (!isLogical(_tidy) || xlength(_tidy) != 1)
+        if (!Rf_isLogical(_tidy) || Rf_xlength(_tidy) != 1)
             verror("\"tidy\" argument must be a logical value");
 
-        if ((!isReal(_threshold) && !isInteger(_threshold)) || xlength(_threshold) != 1)
+        if ((!Rf_isReal(_threshold) && !Rf_isInteger(_threshold)) || Rf_xlength(_threshold) != 1)
             verror("\"threshold\" argument must be a numeric value");
 
-        SEXP rdim = getAttrib(_x, R_DimSymbol);
+        SEXP rdim = Rf_getAttrib(_x, R_DimSymbol);
 
-        if (!isInteger(rdim) || xlength(rdim) != 2)
+        if (!Rf_isInteger(rdim) || Rf_xlength(rdim) != 2)
             verror("\"x\" argument must be a matrix of numeric values");
 
-        bool pairwise_complete_obs = asLogical(_pairwise_complete_obs);
-        bool spearman = asLogical(_spearman);
-        bool tidy = asLogical(_tidy);
-        double threshold = fabs(asReal(_threshold));
-        uint64_t num_rows = nrows(_x);
-        uint64_t num_cols = ncols(_x);
+        bool pairwise_complete_obs = Rf_asLogical(_pairwise_complete_obs);
+        bool spearman = Rf_asLogical(_spearman);
+        bool tidy = Rf_asLogical(_tidy);
+        double threshold = fabs(Rf_asReal(_threshold));
+        uint64_t num_rows = Rf_nrows(_x);
+        uint64_t num_cols = Rf_ncols(_x);
 
         if (num_rows < 1 || num_cols < 1)
             verror("\"x\" argument must be a matrix of numeric values");
@@ -84,12 +87,12 @@ SEXP tgs_cor(SEXP _x, SEXP _pairwise_complete_obs, SEXP _spearman, SEXP _tidy, S
         vals.reserve(num_vals);
 
         for (uint64_t i = 0; i < num_vals; ++i) {
-            if ((isReal(_x) && !R_FINITE(REAL(_x)[i])) || (isInteger(_x) && INTEGER(_x)[i] == NA_INTEGER)) {
+            if ((Rf_isReal(_x) && !R_FINITE(REAL(_x)[i])) || (Rf_isInteger(_x) && INTEGER(_x)[i] == NA_INTEGER)) {
                 nan_in_col[i / num_rows] = true;
                 nan_in_vals = true;
                 vals.push_back(numeric_limits<double>::quiet_NaN());
             } else
-                vals.push_back(isReal(_x) ? REAL(_x)[i] : INTEGER(_x)[i]);
+                vals.push_back(Rf_isReal(_x) ? REAL(_x)[i] : INTEGER(_x)[i]);
         }
 
         // replace values with ranks if spearman=T
@@ -287,8 +290,8 @@ SEXP tgs_cor(SEXP _x, SEXP _pairwise_complete_obs, SEXP _spearman, SEXP _tidy, S
         progress.report_last();
 
         // assemble the answer
-        SEXP rold_dimnames = getAttrib(_x, R_DimNamesSymbol);
-        SEXP rold_colnames = !isNull(rold_dimnames) && xlength(rold_dimnames) == 2 ? VECTOR_ELT(rold_dimnames, 1) : R_NilValue;
+        SEXP rold_dimnames = Rf_getAttrib(_x, R_DimNamesSymbol);
+        SEXP rold_colnames = !Rf_isNull(rold_dimnames) && Rf_xlength(rold_dimnames) == 2 ? VECTOR_ELT(rold_dimnames, 1) : R_NilValue;
 
         if (tidy) {
             enum { COL1, COL2, COR, NUM_COLS };
@@ -318,7 +321,7 @@ SEXP tgs_cor(SEXP _x, SEXP _pairwise_complete_obs, SEXP _spearman, SEXP _tidy, S
             rprotect(rrownames = RSaneAllocVector(INTSXP, answer_size));
 
             for (int i = 0; i < NUM_COLS; i++)
-                SET_STRING_ELT(rcolnames, i, mkChar(COL_NAMES[i]));
+                SET_STRING_ELT(rcolnames, i, Rf_mkChar(COL_NAMES[i]));
 
             if (answer_size) {
                 uint64_t i = 0;
@@ -337,19 +340,19 @@ SEXP tgs_cor(SEXP _x, SEXP _pairwise_complete_obs, SEXP _spearman, SEXP _tidy, S
             }
 
             if (rold_colnames != R_NilValue) {
-                setAttrib(rcol1, R_LevelsSymbol, rold_colnames);
-                setAttrib(rcol1, R_ClassSymbol, mkString("factor"));
-                setAttrib(rcol2, R_LevelsSymbol, rold_colnames);
-                setAttrib(rcol2, R_ClassSymbol, mkString("factor"));
+                Rf_setAttrib(rcol1, R_LevelsSymbol, rold_colnames);
+                Rf_setAttrib(rcol1, R_ClassSymbol, Rf_mkString("factor"));
+                Rf_setAttrib(rcol2, R_LevelsSymbol, rold_colnames);
+                Rf_setAttrib(rcol2, R_ClassSymbol, Rf_mkString("factor"));
             }
 
             SET_VECTOR_ELT(answer, COL1, rcol1);
             SET_VECTOR_ELT(answer, COL2, rcol2);
             SET_VECTOR_ELT(answer, COR, rcor);
 
-            setAttrib(answer, R_NamesSymbol, rcolnames);
-            setAttrib(answer, R_ClassSymbol, mkString("data.frame"));
-            setAttrib(answer, R_RowNamesSymbol, rrownames);
+            Rf_setAttrib(answer, R_NamesSymbol, rcolnames);
+            Rf_setAttrib(answer, R_ClassSymbol, Rf_mkString("data.frame"));
+            Rf_setAttrib(answer, R_RowNamesSymbol, rrownames);
         } else {
             // copy the matrix below the diagonal to the upper part (the two parts are identical since cor(X,Y)=cor(Y,X)
             for (uint64_t icol1 = 0; icol1 < (uint64_t)num_cols; ++icol1) {
@@ -376,14 +379,14 @@ SEXP tgs_cor(SEXP _x, SEXP _pairwise_complete_obs, SEXP _spearman, SEXP _tidy, S
             rprotect(dim = RSaneAllocVector(INTSXP, 2));
             INTEGER(dim)[0] = num_cols;
             INTEGER(dim)[1] = num_cols;
-            setAttrib(answer, R_DimSymbol, dim);
+            Rf_setAttrib(answer, R_DimSymbol, dim);
 
             if (rold_colnames != R_NilValue) {
                 SEXP dimnames;
                 rprotect(dimnames = RSaneAllocVector(VECSXP, 2));
                 SET_VECTOR_ELT(dimnames, 0, rold_colnames);
                 SET_VECTOR_ELT(dimnames, 1, rold_colnames);
-                setAttrib(answer, R_DimNamesSymbol, dimnames);
+                Rf_setAttrib(answer, R_DimNamesSymbol, dimnames);
             }
         }
     } catch (TGLException &e) {
@@ -412,42 +415,42 @@ SEXP tgs_cross_cor(SEXP _x, SEXP _y, SEXP _pairwise_complete_obs, SEXP _spearman
 	try {
         TGStat tgstat(_envir);
 
-		if ((!isReal(_x) && !isInteger(_x)) || xlength(_x) < 1)
+		if ((!Rf_isReal(_x) && !Rf_isInteger(_x)) || Rf_xlength(_x) < 1)
 			verror("\"x\" argument must be a matrix of numeric values");
 
-        if ((!isReal(_y) && !isInteger(_y)) || xlength(_y) < 1)
+        if ((!Rf_isReal(_y) && !Rf_isInteger(_y)) || Rf_xlength(_y) < 1)
             verror("\"y\" argument must be a matrix of numeric values");
 
-        if (!isLogical(_pairwise_complete_obs) || xlength(_pairwise_complete_obs) != 1)
+        if (!Rf_isLogical(_pairwise_complete_obs) || Rf_xlength(_pairwise_complete_obs) != 1)
             verror("\"pairwise.complete.obs\" argument must be a logical value");
 
-        if (!isLogical(_spearman) || xlength(_spearman) != 1)
+        if (!Rf_isLogical(_spearman) || Rf_xlength(_spearman) != 1)
             verror("\"spearman\" argument must be a logical value");
 
-        if (!isLogical(_tidy) || xlength(_tidy) != 1)
+        if (!Rf_isLogical(_tidy) || Rf_xlength(_tidy) != 1)
             verror("\"tidy\" argument must be a logical value");
 
-        if ((!isReal(_threshold) && !isInteger(_threshold)) || xlength(_threshold) != 1)
+        if ((!Rf_isReal(_threshold) && !Rf_isInteger(_threshold)) || Rf_xlength(_threshold) != 1)
             verror("\"threshold\" argument must be a numeric value");
 
-        SEXP rdim1 = getAttrib(_x, R_DimSymbol);
-        SEXP rdim2 = getAttrib(_y, R_DimSymbol);
+        SEXP rdim1 = Rf_getAttrib(_x, R_DimSymbol);
+        SEXP rdim2 = Rf_getAttrib(_y, R_DimSymbol);
 
-        if (!isInteger(rdim1) || xlength(rdim1) != 2)
+        if (!Rf_isInteger(rdim1) || Rf_xlength(rdim1) != 2)
             verror("\"x\" argument must be a matrix of numeric values");
 
-        if (!isInteger(rdim2) || xlength(rdim2) != 2)
+        if (!Rf_isInteger(rdim2) || Rf_xlength(rdim2) != 2)
             verror("\"y\" argument must be a matrix of numeric values");
 
-        if (nrows(_x) != nrows(_y))
+        if (Rf_nrows(_x) != Rf_nrows(_y))
             verror("\"x\" and \"y\" matrices have different number of rows");
 
-        bool pairwise_complete_obs = asLogical(_pairwise_complete_obs);
-        bool spearman = asLogical(_spearman);
-        bool tidy = asLogical(_tidy);
-        double threshold = fabs(asReal(_threshold));
-        uint64_t num_rows = nrows(_x);
-        uint64_t num_cols[2] = { (uint64_t)ncols(_x), (uint64_t)ncols(_y) };
+        bool pairwise_complete_obs = Rf_asLogical(_pairwise_complete_obs);
+        bool spearman = Rf_asLogical(_spearman);
+        bool tidy = Rf_asLogical(_tidy);
+        double threshold = fabs(Rf_asReal(_threshold));
+        uint64_t num_rows = Rf_nrows(_x);
+        uint64_t num_cols[2] = { (uint64_t)Rf_ncols(_x), (uint64_t)Rf_ncols(_y) };
 
         if (num_rows < 1 || num_cols[0] < 1)
             verror("\"x\" argument must be a matrix of numeric values");
@@ -484,12 +487,12 @@ SEXP tgs_cross_cor(SEXP _x, SEXP _y, SEXP _pairwise_complete_obs, SEXP _spearman
             SEXP x = k ? _y : _x;
 
             for (uint64_t i = 0; i < num_vals[k]; ++i) {
-                if ((isReal(x) && !R_FINITE(REAL(x)[i])) || (isInteger(x) && INTEGER(x)[i] == NA_INTEGER)) {
+                if ((Rf_isReal(x) && !R_FINITE(REAL(x)[i])) || (Rf_isInteger(x) && INTEGER(x)[i] == NA_INTEGER)) {
                     nan_in_col[k][i / num_rows] = true;
                     nan_in_vals = true;
                     vals[k].push_back(numeric_limits<double>::quiet_NaN());
                 } else
-                    vals[k].push_back(isReal(x) ? REAL(x)[i] : INTEGER(x)[i]);
+                    vals[k].push_back(Rf_isReal(x) ? REAL(x)[i] : INTEGER(x)[i]);
             }
         }
 
@@ -688,10 +691,10 @@ SEXP tgs_cross_cor(SEXP _x, SEXP _y, SEXP _pairwise_complete_obs, SEXP _spearman
         progress.report_last();
 
         // assemble the answer
-        SEXP rold_dimnames[2] = { getAttrib(_x, R_DimNamesSymbol), getAttrib(_y, R_DimNamesSymbol) };
+        SEXP rold_dimnames[2] = { Rf_getAttrib(_x, R_DimNamesSymbol), Rf_getAttrib(_y, R_DimNamesSymbol) };
         SEXP rold_colnames[2] = {
-            !isNull(rold_dimnames[0]) && xlength(rold_dimnames[0]) == 2 ? VECTOR_ELT(rold_dimnames[0], 1) : R_NilValue,
-            !isNull(rold_dimnames[1]) && xlength(rold_dimnames[1]) == 2 ? VECTOR_ELT(rold_dimnames[1], 1) : R_NilValue
+            !Rf_isNull(rold_dimnames[0]) && Rf_xlength(rold_dimnames[0]) == 2 ? VECTOR_ELT(rold_dimnames[0], 1) : R_NilValue,
+            !Rf_isNull(rold_dimnames[1]) && Rf_xlength(rold_dimnames[1]) == 2 ? VECTOR_ELT(rold_dimnames[1], 1) : R_NilValue
         };
 
         if (tidy) {
@@ -716,7 +719,7 @@ SEXP tgs_cross_cor(SEXP _x, SEXP _y, SEXP _pairwise_complete_obs, SEXP _spearman
             rprotect(rrownames = RSaneAllocVector(INTSXP, answer_size));
 
             for (int i = 0; i < NUM_COLS; i++)
-                SET_STRING_ELT(rcolnames, i, mkChar(COL_NAMES[i]));
+                SET_STRING_ELT(rcolnames, i, Rf_mkChar(COL_NAMES[i]));
 
             if (answer_size) {
                 uint64_t idx_answer = 0;
@@ -736,21 +739,21 @@ SEXP tgs_cross_cor(SEXP _x, SEXP _y, SEXP _pairwise_complete_obs, SEXP _spearman
             }
 
             if (rold_colnames[0] != R_NilValue) {
-                setAttrib(rcol1, R_LevelsSymbol, rold_colnames[0]);
-                setAttrib(rcol1, R_ClassSymbol, mkString("factor"));
+                Rf_setAttrib(rcol1, R_LevelsSymbol, rold_colnames[0]);
+                Rf_setAttrib(rcol1, R_ClassSymbol, Rf_mkString("factor"));
             }
             if (rold_colnames[1] != R_NilValue) {
-                setAttrib(rcol2, R_LevelsSymbol, rold_colnames[1]);
-                setAttrib(rcol2, R_ClassSymbol, mkString("factor"));
+                Rf_setAttrib(rcol2, R_LevelsSymbol, rold_colnames[1]);
+                Rf_setAttrib(rcol2, R_ClassSymbol, Rf_mkString("factor"));
             }
 
             SET_VECTOR_ELT(answer, COL1, rcol1);
             SET_VECTOR_ELT(answer, COL2, rcol2);
             SET_VECTOR_ELT(answer, COR, rcor);
 
-            setAttrib(answer, R_NamesSymbol, rcolnames);
-            setAttrib(answer, R_ClassSymbol, mkString("data.frame"));
-            setAttrib(answer, R_RowNamesSymbol, rrownames);
+            Rf_setAttrib(answer, R_NamesSymbol, rcolnames);
+            Rf_setAttrib(answer, R_ClassSymbol, Rf_mkString("data.frame"));
+            Rf_setAttrib(answer, R_RowNamesSymbol, rrownames);
         } else {
             SEXP dim;
             SEXP dimnames;
@@ -766,12 +769,12 @@ SEXP tgs_cross_cor(SEXP _x, SEXP _y, SEXP _pairwise_complete_obs, SEXP _spearman
             rprotect(dim = RSaneAllocVector(INTSXP, 2));
             INTEGER(dim)[0] = num_cols[0];
             INTEGER(dim)[1] = num_cols[1];
-            setAttrib(answer, R_DimSymbol, dim);
+            Rf_setAttrib(answer, R_DimSymbol, dim);
 
             rprotect(dimnames = RSaneAllocVector(VECSXP, 2));
             SET_VECTOR_ELT(dimnames, 0, rold_colnames[0]);
             SET_VECTOR_ELT(dimnames, 1, rold_colnames[1]);
-            setAttrib(answer, R_DimNamesSymbol, dimnames);
+            Rf_setAttrib(answer, R_DimNamesSymbol, dimnames);
         }
     } catch (TGLException &e) {
         if (!TGStat::is_kid() && res != (double *)MAP_FAILED) {
@@ -808,32 +811,32 @@ SEXP tgs_cor_blas(SEXP _x, SEXP _pairwise_complete_obs, SEXP _spearman, SEXP _ti
 
         TGStat tgstat(_envir);
 
-        if ((!isReal(_x) && !isInteger(_x)) || xlength(_x) < 1)
+        if ((!Rf_isReal(_x) && !Rf_isInteger(_x)) || Rf_xlength(_x) < 1)
             verror("\"x\" argument must be a matrix of numeric values");
 
-        if (!isLogical(_pairwise_complete_obs) || xlength(_pairwise_complete_obs) != 1)
+        if (!Rf_isLogical(_pairwise_complete_obs) || Rf_xlength(_pairwise_complete_obs) != 1)
             verror("\"pairwise.complete.obs\" argument must be a logical value");
 
-        if (!isLogical(_spearman) || xlength(_spearman) != 1)
+        if (!Rf_isLogical(_spearman) || Rf_xlength(_spearman) != 1)
             verror("\"spearman\" argument must be a logical value");
 
-        if (!isLogical(_tidy) || xlength(_tidy) != 1)
+        if (!Rf_isLogical(_tidy) || Rf_xlength(_tidy) != 1)
             verror("\"tidy\" argument must be a logical value");
 
-        if ((!isReal(_threshold) && !isInteger(_threshold)) || xlength(_threshold) != 1)
+        if ((!Rf_isReal(_threshold) && !Rf_isInteger(_threshold)) || Rf_xlength(_threshold) != 1)
             verror("\"threshold\" argument must be a numeric value");
 
-        SEXP rdim = getAttrib(_x, R_DimSymbol);
+        SEXP rdim = Rf_getAttrib(_x, R_DimSymbol);
 
-        if (!isInteger(rdim) || xlength(rdim) != 2)
+        if (!Rf_isInteger(rdim) || Rf_xlength(rdim) != 2)
             verror("\"x\" argument must be a matrix of numeric values");
 
-        bool pairwise_complete_obs = asLogical(_pairwise_complete_obs);
-        bool spearman = asLogical(_spearman);
-        bool tidy = asLogical(_tidy);
-        double threshold = fabs(asReal(_threshold));
-        uint64_t num_dims = nrows(_x);
-        uint64_t num_points = ncols(_x);
+        bool pairwise_complete_obs = Rf_asLogical(_pairwise_complete_obs);
+        bool spearman = Rf_asLogical(_spearman);
+        bool tidy = Rf_asLogical(_tidy);
+        double threshold = fabs(Rf_asReal(_threshold));
+        uint64_t num_dims = Rf_nrows(_x);
+        uint64_t num_points = Rf_ncols(_x);
         int num_dims32 = (int)num_dims;
         int num_points32 = (int)num_points;
 
@@ -854,12 +857,12 @@ SEXP tgs_cor_blas(SEXP _x, SEXP _pairwise_complete_obs, SEXP _spearman, SEXP _ti
             verror("%s", strerror(errno));
 
         for (uint64_t i = 0; i < num_vals; ++i) {
-            if ((isReal(_x) && !R_FINITE(REAL(_x)[i])) || (isInteger(_x) && INTEGER(_x)[i] == NA_INTEGER)) {
+            if ((Rf_isReal(_x) && !R_FINITE(REAL(_x)[i])) || (Rf_isInteger(_x) && INTEGER(_x)[i] == NA_INTEGER)) {
                 mem.m[i] = mem.mask[i] = 0.;
                 nan_in_vals = true;
                 nan_in_point[i / num_dims] = true;
             } else {
-                double val = isReal(_x) ? REAL(_x)[i] : INTEGER(_x)[i];
+                double val = Rf_isReal(_x) ? REAL(_x)[i] : INTEGER(_x)[i];
                 mem.m[i] = val;
                 mem.mask[i] = 1.;
             }
@@ -1098,15 +1101,15 @@ SEXP tgs_cor_blas(SEXP _x, SEXP _pairwise_complete_obs, SEXP _spearman, SEXP _ti
 //rprotect(answer = RSaneAllocVector(REALSXP, (uint64_t)num_points * num_points));
 //rprotect(rdims = RSaneAllocVector(INTSXP, 2));
 //INTEGER(rdims)[0] = INTEGER(rdims)[1] = num_points;
-//setAttrib(answer, R_DimSymbol, rdims);
+//Rf_setAttrib(answer, R_DimSymbol, rdims);
 //memcpy(REAL(answer), mem.res, Rf_length(answer) * sizeof(REAL(answer)[0]));
 //return answer;
 //}
 
 
         // assemble the answer
-        SEXP rold_dimnames = getAttrib(_x, R_DimNamesSymbol);
-        SEXP rold_colnames = !isNull(rold_dimnames) && xlength(rold_dimnames) == 2 ? VECTOR_ELT(rold_dimnames, 1) : R_NilValue;
+        SEXP rold_dimnames = Rf_getAttrib(_x, R_DimNamesSymbol);
+        SEXP rold_colnames = !Rf_isNull(rold_dimnames) && Rf_xlength(rold_dimnames) == 2 ? VECTOR_ELT(rold_dimnames, 1) : R_NilValue;
 
         if (tidy) {
             enum { COL1, COL2, COR, NUM_COLS };
@@ -1134,7 +1137,7 @@ SEXP tgs_cor_blas(SEXP _x, SEXP _pairwise_complete_obs, SEXP _spearman, SEXP _ti
             rprotect(rrownames = RSaneAllocVector(INTSXP, answer_size));
 
             for (int i = 0; i < NUM_COLS; i++)
-                SET_STRING_ELT(rcolnames, i, mkChar(COL_NAMES[i]));
+                SET_STRING_ELT(rcolnames, i, Rf_mkChar(COL_NAMES[i]));
 
             if (answer_size) {
                 uint64_t i = 0;
@@ -1153,19 +1156,19 @@ SEXP tgs_cor_blas(SEXP _x, SEXP _pairwise_complete_obs, SEXP _spearman, SEXP _ti
             }
 
             if (rold_colnames != R_NilValue) {
-                setAttrib(rcol1, R_LevelsSymbol, rold_colnames);
-                setAttrib(rcol1, R_ClassSymbol, mkString("factor"));
-                setAttrib(rcol2, R_LevelsSymbol, rold_colnames);
-                setAttrib(rcol2, R_ClassSymbol, mkString("factor"));
+                Rf_setAttrib(rcol1, R_LevelsSymbol, rold_colnames);
+                Rf_setAttrib(rcol1, R_ClassSymbol, Rf_mkString("factor"));
+                Rf_setAttrib(rcol2, R_LevelsSymbol, rold_colnames);
+                Rf_setAttrib(rcol2, R_ClassSymbol, Rf_mkString("factor"));
             }
 
             SET_VECTOR_ELT(answer, COL1, rcol1);
             SET_VECTOR_ELT(answer, COL2, rcol2);
             SET_VECTOR_ELT(answer, COR, rcor);
 
-            setAttrib(answer, R_NamesSymbol, rcolnames);
-            setAttrib(answer, R_ClassSymbol, mkString("data.frame"));
-            setAttrib(answer, R_RowNamesSymbol, rrownames);
+            Rf_setAttrib(answer, R_NamesSymbol, rcolnames);
+            Rf_setAttrib(answer, R_ClassSymbol, Rf_mkString("data.frame"));
+            Rf_setAttrib(answer, R_RowNamesSymbol, rrownames);
         } else {
             SEXP dim;
 
@@ -1180,14 +1183,14 @@ SEXP tgs_cor_blas(SEXP _x, SEXP _pairwise_complete_obs, SEXP _spearman, SEXP _ti
             rprotect(dim = RSaneAllocVector(INTSXP, 2));
             INTEGER(dim)[0] = num_points;
             INTEGER(dim)[1] = num_points;
-            setAttrib(answer, R_DimSymbol, dim);
+            Rf_setAttrib(answer, R_DimSymbol, dim);
 
             if (rold_colnames != R_NilValue) {
                 SEXP dimnames;
                 rprotect(dimnames = RSaneAllocVector(VECSXP, 2));
                 SET_VECTOR_ELT(dimnames, 0, rold_colnames);
                 SET_VECTOR_ELT(dimnames, 1, rold_colnames);
-                setAttrib(answer, R_DimNamesSymbol, dimnames);
+                Rf_setAttrib(answer, R_DimNamesSymbol, dimnames);
             }
         }
     } catch (TGLException &e) {
@@ -1231,42 +1234,42 @@ SEXP tgs_cross_cor_blas(SEXP _x, SEXP _y, SEXP _pairwise_complete_obs, SEXP _spe
 
         TGStat tgstat(_envir);
 
-        if ((!isReal(_x) && !isInteger(_x)) || xlength(_x) < 1)
+        if ((!Rf_isReal(_x) && !Rf_isInteger(_x)) || Rf_xlength(_x) < 1)
             verror("\"x\" argument must be a matrix of numeric values");
 
-        if ((!isReal(_y) && !isInteger(_y)) || xlength(_y) < 1)
+        if ((!Rf_isReal(_y) && !Rf_isInteger(_y)) || Rf_xlength(_y) < 1)
             verror("\"y\" argument must be a matrix of numeric values");
 
-        if (!isLogical(_pairwise_complete_obs) || xlength(_pairwise_complete_obs) != 1)
+        if (!Rf_isLogical(_pairwise_complete_obs) || Rf_xlength(_pairwise_complete_obs) != 1)
             verror("\"pairwise.complete.obs\" argument must be a logical value");
 
-        if (!isLogical(_spearman) || xlength(_spearman) != 1)
+        if (!Rf_isLogical(_spearman) || Rf_xlength(_spearman) != 1)
             verror("\"spearman\" argument must be a logical value");
 
-        if (!isLogical(_tidy) || xlength(_tidy) != 1)
+        if (!Rf_isLogical(_tidy) || Rf_xlength(_tidy) != 1)
             verror("\"tidy\" argument must be a logical value");
 
-        if ((!isReal(_threshold) && !isInteger(_threshold)) || xlength(_threshold) != 1)
+        if ((!Rf_isReal(_threshold) && !Rf_isInteger(_threshold)) || Rf_xlength(_threshold) != 1)
             verror("\"threshold\" argument must be a numeric value");
 
-        SEXP rdim1 = getAttrib(_x, R_DimSymbol);
-        SEXP rdim2 = getAttrib(_y, R_DimSymbol);
+        SEXP rdim1 = Rf_getAttrib(_x, R_DimSymbol);
+        SEXP rdim2 = Rf_getAttrib(_y, R_DimSymbol);
 
-        if (!isInteger(rdim1) || xlength(rdim1) != 2)
+        if (!Rf_isInteger(rdim1) || Rf_xlength(rdim1) != 2)
             verror("\"x\" argument must be a matrix of numeric values");
 
-        if (!isInteger(rdim2) || xlength(rdim2) != 2)
+        if (!Rf_isInteger(rdim2) || Rf_xlength(rdim2) != 2)
             verror("\"y\" argument must be a matrix of numeric values");
 
-        if (nrows(_x) != nrows(_y))
+        if (Rf_nrows(_x) != Rf_nrows(_y))
             verror("\"x\" and \"y\" matrices have different number of rows");
 
-        bool pairwise_complete_obs = asLogical(_pairwise_complete_obs);
-        bool spearman = asLogical(_spearman);
-        bool tidy = asLogical(_tidy);
-        double threshold = fabs(asReal(_threshold));
-        uint64_t num_dims = nrows(_x);
-        uint64_t num_points[2] = { (uint64_t)ncols(_x), (uint64_t)ncols(_y) };
+        bool pairwise_complete_obs = Rf_asLogical(_pairwise_complete_obs);
+        bool spearman = Rf_asLogical(_spearman);
+        bool tidy = Rf_asLogical(_tidy);
+        double threshold = fabs(Rf_asReal(_threshold));
+        uint64_t num_dims = Rf_nrows(_x);
+        uint64_t num_points[2] = { (uint64_t)Rf_ncols(_x), (uint64_t)Rf_ncols(_y) };
         int num_dims32 = (int)num_dims;
         int num_points32[2] = { (int)num_points[0], (int)num_points[1] };
 
@@ -1294,12 +1297,12 @@ SEXP tgs_cross_cor_blas(SEXP _x, SEXP _y, SEXP _pairwise_complete_obs, SEXP _spe
             SEXP x = k ? _y : _x;
 
             for (uint64_t i = 0; i < num_vals[k]; ++i) {
-                if ((isReal(x) && !R_FINITE(REAL(x)[i])) || (isInteger(x) && INTEGER(x)[i] == NA_INTEGER)) {
+                if ((Rf_isReal(x) && !R_FINITE(REAL(x)[i])) || (Rf_isInteger(x) && INTEGER(x)[i] == NA_INTEGER)) {
                     mem.m[k][i] = mem.mask[k][i] = 0.;
                     nan_in_vals = true;
                     nan_in_point[k][i / num_dims] = true;
                 } else {
-                    double val = isReal(x) ? REAL(x)[i] : INTEGER(x)[i];
+                    double val = Rf_isReal(x) ? REAL(x)[i] : INTEGER(x)[i];
                     mem.m[k][i] = val;
                     mem.mask[k][i] = 1.;
                 }
@@ -1538,10 +1541,10 @@ SEXP tgs_cross_cor_blas(SEXP _x, SEXP _y, SEXP _pairwise_complete_obs, SEXP _spe
         vdebug("END BLAS COR\n");
 
         // assemble the answer
-        SEXP rold_dimnames[2] = { getAttrib(_x, R_DimNamesSymbol), getAttrib(_y, R_DimNamesSymbol) };
+        SEXP rold_dimnames[2] = { Rf_getAttrib(_x, R_DimNamesSymbol), Rf_getAttrib(_y, R_DimNamesSymbol) };
         SEXP rold_colnames[2] = {
-            !isNull(rold_dimnames[0]) && xlength(rold_dimnames[0]) == 2 ? VECTOR_ELT(rold_dimnames[0], 1) : R_NilValue,
-            !isNull(rold_dimnames[1]) && xlength(rold_dimnames[1]) == 2 ? VECTOR_ELT(rold_dimnames[1], 1) : R_NilValue
+            !Rf_isNull(rold_dimnames[0]) && Rf_xlength(rold_dimnames[0]) == 2 ? VECTOR_ELT(rold_dimnames[0], 1) : R_NilValue,
+            !Rf_isNull(rold_dimnames[1]) && Rf_xlength(rold_dimnames[1]) == 2 ? VECTOR_ELT(rold_dimnames[1], 1) : R_NilValue
         };
 
         if (tidy) {
@@ -1566,7 +1569,7 @@ SEXP tgs_cross_cor_blas(SEXP _x, SEXP _y, SEXP _pairwise_complete_obs, SEXP _spe
             rprotect(rrownames = RSaneAllocVector(INTSXP, answer_size));
 
             for (int i = 0; i < NUM_COLS; i++)
-                SET_STRING_ELT(rcolnames, i, mkChar(COL_NAMES[i]));
+                SET_STRING_ELT(rcolnames, i, Rf_mkChar(COL_NAMES[i]));
 
             if (answer_size) {
                 uint64_t idx_answer = 0;
@@ -1586,21 +1589,21 @@ SEXP tgs_cross_cor_blas(SEXP _x, SEXP _y, SEXP _pairwise_complete_obs, SEXP _spe
             }
 
             if (rold_colnames[0] != R_NilValue) {
-                setAttrib(rcol1, R_LevelsSymbol, rold_colnames[0]);
-                setAttrib(rcol1, R_ClassSymbol, mkString("factor"));
+                Rf_setAttrib(rcol1, R_LevelsSymbol, rold_colnames[0]);
+                Rf_setAttrib(rcol1, R_ClassSymbol, Rf_mkString("factor"));
             }
             if (rold_colnames[1] != R_NilValue) {
-                setAttrib(rcol2, R_LevelsSymbol, rold_colnames[1]);
-                setAttrib(rcol2, R_ClassSymbol, mkString("factor"));
+                Rf_setAttrib(rcol2, R_LevelsSymbol, rold_colnames[1]);
+                Rf_setAttrib(rcol2, R_ClassSymbol, Rf_mkString("factor"));
             }
 
             SET_VECTOR_ELT(answer, COL1, rcol1);
             SET_VECTOR_ELT(answer, COL2, rcol2);
             SET_VECTOR_ELT(answer, COR, rcor);
 
-            setAttrib(answer, R_NamesSymbol, rcolnames);
-            setAttrib(answer, R_ClassSymbol, mkString("data.frame"));
-            setAttrib(answer, R_RowNamesSymbol, rrownames);
+            Rf_setAttrib(answer, R_NamesSymbol, rcolnames);
+            Rf_setAttrib(answer, R_ClassSymbol, Rf_mkString("data.frame"));
+            Rf_setAttrib(answer, R_RowNamesSymbol, rrownames);
         } else {
             SEXP dim;
             SEXP dimnames;
@@ -1616,12 +1619,12 @@ SEXP tgs_cross_cor_blas(SEXP _x, SEXP _y, SEXP _pairwise_complete_obs, SEXP _spe
             rprotect(dim = RSaneAllocVector(INTSXP, 2));
             INTEGER(dim)[0] = num_points[0];
             INTEGER(dim)[1] = num_points[1];
-            setAttrib(answer, R_DimSymbol, dim);
+            Rf_setAttrib(answer, R_DimSymbol, dim);
 
             rprotect(dimnames = RSaneAllocVector(VECSXP, 2));
             SET_VECTOR_ELT(dimnames, 0, rold_colnames[0]);
             SET_VECTOR_ELT(dimnames, 1, rold_colnames[1]);
-            setAttrib(answer, R_DimNamesSymbol, dimnames);
+            Rf_setAttrib(answer, R_DimNamesSymbol, dimnames);
         }
     } catch (TGLException &e) {
         rerror("%s", e.msg());
